/*******************************************************************************
 * Copyright 2012 pw999
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *   http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 ******************************************************************************/
package net.sf.oqt.core;

import java.text.MessageFormat;
import java.util.Collection;
import java.util.TreeSet;

import net.sf.oqt.model.EntityVO;
import net.sf.oqt.model.PackageVO;
import net.sf.oqt.model.ResultVO;


/**
 * Contains all the configuration settings.
 * 
 * @author phillip
 * 
 */
public class CoreProperties {

    CoreProperties() {

    }

    /**
     * Database connection url.
     */
    private String url = "";
    /**
     * Database username. Leave empty if not required.
     */
    private String username = "";
    /**
     * Database password. Leave empty if not required.
     */
    private String password = "";
    /**
     * Database driver name. Must be on the classPath.
     */
    private String driverName = "";
    /**
     * Database dictionary. Must be known to the OpenJPA version on the
     * classpath.
     */
    private String dictionary = "";
    /**
     * The list of package names where the application can find the JPA
     * entities.
     */
    private final Collection<String> packageNames = new TreeSet<String>();
    /**
     * List of fully qualified names of the JPA entities.
     */
    private final Collection<String> fqns = new TreeSet<String>();
    /**
     * The version of openJPA. This is automatically initialized when the {@link CoreFactory#getEntityManager()} method
     * is called.
     */
    private String jpaVersion = "";

    public final String getUrl() {
        return url;
    }

    public final void setUrl(final String url) {
        this.url = url;
    }

    public final String getUsername() {
        return username;
    }

    public final void setUsername(final String username) {
        this.username = username;
    }

    public final String getPassword() {
        return password;
    }

    public final void setPassword(final String password) {
        this.password = password;
    }

    public final String getDriverName() {
        return driverName;
    }

    public final void setDriverName(final String driverName) {
        this.driverName = driverName;
    }

    public final String getDictionary() {
        return dictionary;
    }

    public final void setDictionary(final String dictionary) {
        this.dictionary = dictionary;
    }

    public final Collection<String> getFqns() {
        return fqns;
    }

    public final Collection<String> getPackageNames() {
        return packageNames;
    }

    public final String getJpaVersion() {
        return jpaVersion;
    }

    final void setJpaVersion(final String jpaVersion) {
        this.jpaVersion = jpaVersion;
    }

    /**
     * Initializes the list of fully qualified names based on the info in the
     * ResultVO object.
     * 
     * @param result the initialized ResultVO
     */
    public final void setFqnsFromResult(final ResultVO result) {
        String pattern = "{0}.{1}";
        fqns.clear();
        Collection<PackageVO> packages = result.getPackages();
        for (final PackageVO packageVO : packages) {
            Collection<EntityVO> entities = packageVO.getEntities();
            for (final EntityVO entityVO : entities) {
                fqns.add(MessageFormat.format(pattern, packageVO.getName(), entityVO.getName()));
            }
        }
    }

}
