/*******************************************************************************
 * Copyright 2012 pw999
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *   http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 ******************************************************************************/
package net.sf.oqt.driver;

import java.sql.Array;
import java.sql.Blob;
import java.sql.CallableStatement;
import java.sql.Clob;
import java.sql.DatabaseMetaData;
import java.sql.NClob;
import java.sql.PreparedStatement;
import java.sql.SQLClientInfoException;
import java.sql.SQLException;
import java.sql.SQLWarning;
import java.sql.SQLXML;
import java.sql.Savepoint;
import java.sql.Statement;
import java.sql.Struct;
import java.util.Map;
import java.util.Properties;
import java.util.concurrent.Executor;

import net.sf.oqt.core.CoreFactory;


class NullConnection implements java.sql.Connection {

    NullConnection() {
    }

    @Override
    public boolean isWrapperFor(final Class<?> arg0) throws SQLException {
        return CoreFactory.getRealConnection().isWrapperFor(arg0);
    }

    @Override
    public <T> T unwrap(final Class<T> arg0) throws SQLException {
        return CoreFactory.getRealConnection().unwrap(arg0);
    }

    @Override
    public void abort(final Executor executor) throws SQLException {

    }

    @Override
    public void clearWarnings() throws SQLException {

    }

    @Override
    public void close() throws SQLException {

    }

    @Override
    public void commit() throws SQLException {

    }

    @Override
    public Array createArrayOf(final String typeName, final Object[] elements) throws SQLException {
        return CoreFactory.getRealConnection().createArrayOf(typeName, elements);
    }

    @Override
    public Blob createBlob() throws SQLException {
        return CoreFactory.getRealConnection().createBlob();
    }

    @Override
    public Clob createClob() throws SQLException {
        return CoreFactory.getRealConnection().createClob();
    }

    @Override
    public NClob createNClob() throws SQLException {
        return CoreFactory.getRealConnection().createNClob();
    }

    @Override
    public SQLXML createSQLXML() throws SQLException {
        return CoreFactory.getRealConnection().createSQLXML();
    }

    @Override
    public Statement createStatement() throws SQLException {
        return null;
    }

    @Override
    public Statement createStatement(final int resultSetType, final int resultSetConcurrency) throws SQLException {
        return null;
    }

    @Override
    public Statement createStatement(final int resultSetType, final int resultSetConcurrency, final int resultSetHoldability) throws SQLException {
        return null;
    }

    @Override
    public Struct createStruct(final String typeName, final Object[] attributes) throws SQLException {
        return CoreFactory.getRealConnection().createStruct(typeName, attributes);
    }

    @Override
    public boolean getAutoCommit() throws SQLException {
        return true;
    }

    @Override
    public String getCatalog() throws SQLException {
        return CoreFactory.getRealConnection().getCatalog();
    }

    @Override
    public Properties getClientInfo() throws SQLException {
        return CoreFactory.getRealConnection().getClientInfo();
    }

    @Override
    public String getClientInfo(final String name) throws SQLException {
        return CoreFactory.getRealConnection().getClientInfo(name);
    }

    @Override
    public int getHoldability() throws SQLException {
        return CoreFactory.getRealConnection().getHoldability();
    }

    @Override
    public DatabaseMetaData getMetaData() throws SQLException {
        return CoreFactory.getRealConnection().getMetaData();
    }

    @Override
    public int getNetworkTimeout() throws SQLException {
        return 0;
    }

    @Override
    public String getSchema() throws SQLException {
        return "nullDriverSchema";
    }

    @Override
    public int getTransactionIsolation() throws SQLException {
        return CoreFactory.getRealConnection().getTransactionIsolation();
    }

    @Override
    public Map<String, Class<?>> getTypeMap() throws SQLException {
        return CoreFactory.getRealConnection().getTypeMap();
    }

    @Override
    public SQLWarning getWarnings() throws SQLException {
        // TODO Auto-generated method stub
        return null;
    }

    @Override
    public boolean isClosed() throws SQLException {
        return false;
    }

    @Override
    public boolean isReadOnly() throws SQLException {
        return false;
    }

    @Override
    public boolean isValid(final int timeout) throws SQLException {
        return true;
    }

    @Override
    public String nativeSQL(final String sql) throws SQLException {
        return null;
    }

    @Override
    public CallableStatement prepareCall(final String sql) throws SQLException {
        return new NullCallableStatement(sql);
    }

    @Override
    public CallableStatement prepareCall(final String sql, final int resultSetType, final int resultSetConcurrency) throws SQLException {
        return new NullCallableStatement(sql);
    }

    @Override
    public CallableStatement prepareCall(final String sql, final int resultSetType, final int resultSetConcurrency, final int resultSetHoldability) throws SQLException {
        return new NullCallableStatement(sql);
    }

    @Override
    public PreparedStatement prepareStatement(final String sql) throws SQLException {
        return new NullPreparedStatement(sql);
    }

    @Override
    public PreparedStatement prepareStatement(final String sql, final int autoGeneratedKeys) throws SQLException {
        return new NullPreparedStatement(sql);
    }

    @Override
    public PreparedStatement prepareStatement(final String sql, final int[] columnIndexes) throws SQLException {
        return new NullPreparedStatement(sql);
    }

    @Override
    public PreparedStatement prepareStatement(final String sql, final String[] columnNames) throws SQLException {
        return new NullPreparedStatement(sql);
    }

    @Override
    public PreparedStatement prepareStatement(final String sql, final int resultSetType, final int resultSetConcurrency) throws SQLException {
        return new NullPreparedStatement(sql);
    }

    @Override
    public PreparedStatement prepareStatement(final String sql, final int resultSetType, final int resultSetConcurrency, final int resultSetHoldability) throws SQLException {
        return new NullPreparedStatement(sql);
    }

    @Override
    public void releaseSavepoint(final Savepoint savepoint) throws SQLException {

    }

    @Override
    public void rollback() throws SQLException {

    }

    @Override
    public void rollback(final Savepoint savepoint) throws SQLException {

    }

    @Override
    public void setAutoCommit(final boolean autoCommit) throws SQLException {

    }

    @Override
    public void setCatalog(final String catalog) throws SQLException {

    }

    @Override
    public void setClientInfo(final Properties properties) throws SQLClientInfoException {

    }

    @Override
    public void setClientInfo(final String name, final String value) throws SQLClientInfoException {

    }

    @Override
    public void setHoldability(final int holdability) throws SQLException {

    }

    @Override
    public void setNetworkTimeout(final Executor executor, final int milliseconds) throws SQLException {

    }

    @Override
    public void setReadOnly(final boolean readOnly) throws SQLException {

    }

    @Override
    public Savepoint setSavepoint() throws SQLException {
        return null;
    }

    @Override
    public Savepoint setSavepoint(final String name) throws SQLException {
        return null;
    }

    @Override
    public void setSchema(final String schema) throws SQLException {

    }

    @Override
    public void setTransactionIsolation(final int level) throws SQLException {

    }

    @Override
    public void setTypeMap(final Map<String, Class<?>> map) throws SQLException {

    }

}
