/*******************************************************************************
 * Copyright 2012 pw999
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *   http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 ******************************************************************************/
package net.sf.oqt.jpa;

import java.math.BigInteger;
import java.util.Date;

/**
 * Factory to initialize whathever has to be initialized to allows proper JPQL execution.
 * 
 * @author phillip
 * 
 */
class ParameterFactory {
    /**
     * Tries to initialized an object of type clazz.
     * 
     * @param clazz the class to initliase.
     * @return the initialized object or an empty String if object could ne be initialized.
     */
    static Object intialize(final Class<?> clazz) {
        if (clazz.equals(Object.class)) { // when using IN statements
            return "";
        }
        try {
            return clazz.newInstance();
        } catch (IllegalAccessException e) {
            ; // it failed,let's do it manually
        } catch (InstantiationException e) {
            ; // it failed,let's do it manually
        }
        if (clazz.equals(Long.class)) {
            return 1L;
        }
        if (clazz.equals(Integer.class)) {
            return 1;
        }
        if (clazz.equals(Short.class)) {
            return Short.valueOf("1");
        }
        if (clazz.equals(BigInteger.class)) {
            return BigInteger.ONE;
        }
        if (clazz.equals(String.class)) {
            return "1";
        }
        if (clazz.equals(Date.class)) {
            return new Date();
        }
        if (clazz.equals(Boolean.class)) {
            return true;
        }
        System.out.println("Unknown parameter type, I'll try a string");
        return "";
    }
}
