/*******************************************************************************
 * Copyright 2012 pw999
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *   http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 ******************************************************************************/
package net.sf.oqt.model;

import java.io.Serializable;
import java.util.ArrayList;
import java.util.Collection;

/**
 * Models a JPA Entity.
 * 
 * @author phillip
 * 
 */
public class EntityVO implements Serializable, Comparable<EntityVO> {

    /**
     * UID
     */
    private static final long serialVersionUID = 6569188216271256792L;

    private final String name;

    private final Collection<QueryVO> queries = new ArrayList<QueryVO>();

    public EntityVO(final String name) {
        this.name = name;
    }

    public final String getName() {
        return name;
    }

    public final Collection<QueryVO> getQueries() {
        return queries;
    }

    @Override
    public int compareTo(final EntityVO o) {
        return getName().compareToIgnoreCase(o.getName());
    }

    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((name == null) ? 0 : name.hashCode());
        return result;
    }

    @Override
    public boolean equals(final Object obj) {
        if (obj instanceof EntityVO) {
            return getName().equalsIgnoreCase(((EntityVO) obj).getName());
        }
        return super.equals(obj);
    }


    
    

}
