/*******************************************************************************
 * Copyright 2012 pw999
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *   http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 ******************************************************************************/
package net.sf.oqt.model;

import java.io.Serializable;
import java.util.ArrayList;
import java.util.Collection;

/**
 * Models a named query.
 * 
 * @author phillip
 * 
 */
public class QueryVO implements Serializable, Comparable<QueryVO> {

    /**
     * UID
     */
    private static final long serialVersionUID = -3293726054842211923L;

    private final String name;

    private final String JPQLQuery;

    private String error = null;

    private final Collection<String> SQLQuery = new ArrayList<String>();

    public QueryVO(final String name, final String jPQLQuery) {
        this.name = name;
        JPQLQuery = jPQLQuery;
    }

    public final String getName() {
        return name;
    }

    public final String getError() {
        return error;
    }

    public final void setError(final String error) {
        this.error = error;
    }

    public final void setError(final Throwable e) {
        this.error = "Exception: " + e.getClass().getSimpleName() + ": " + e.getMessage();
    }

    public final String getJPQLQuery() {
        return JPQLQuery;
    }

    public final Collection<String> getSQLQuery() {
        return SQLQuery;
    }

    @Override
    public int compareTo(final QueryVO o) {
        return getName().compareToIgnoreCase(o.getName());
    }

    public boolean isValid() {
        if (error == null) {
            return true;
        } else if (error.isEmpty()) {
            return true;
        }
        return false;
    }

    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((name == null) ? 0 : name.hashCode());
        return result;
    }

    @Override
    public boolean equals(final Object obj) {
        if (obj instanceof QueryVO) {
            return getName().equals(((QueryVO) obj).getName());
        }
        return super.equals(obj);
    }


}
